==> kubernetes-model-resource-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimSchedulingStatusFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface ResourceClaimSchedulingStatusFluent<A extends ResourceClaimSchedulingStatusFluent<A>> extends Fluent<A>{
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public A addToUnsuitableNodes(Integer index,String item);
  public A setToUnsuitableNodes(Integer index,String item);
  public A addToUnsuitableNodes(java.lang.String... items);
  public A addAllToUnsuitableNodes(Collection<String> items);
  public A removeFromUnsuitableNodes(java.lang.String... items);
  public A removeAllFromUnsuitableNodes(Collection<String> items);
  public List<String> getUnsuitableNodes();
  public String getUnsuitableNode(Integer index);
  public String getFirstUnsuitableNode();
  public String getLastUnsuitableNode();
  public String getMatchingUnsuitableNode(Predicate<String> predicate);
  public Boolean hasMatchingUnsuitableNode(Predicate<String> predicate);
  public A withUnsuitableNodes(List<String> unsuitableNodes);
  public A withUnsuitableNodes(java.lang.String... unsuitableNodes);
  public Boolean hasUnsuitableNodes();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> kubernetes-model-resource-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimSchedulingStatusFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceClaimSchedulingStatusFluent<A extends ResourceClaimSchedulingStatusFluent<A>> extends Fluent<A>{
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public A addToUnsuitableNodes(int index,String item);
  public A setToUnsuitableNodes(int index,String item);
  public A addToUnsuitableNodes(java.lang.String... items);
  public A addAllToUnsuitableNodes(Collection<String> items);
  public A removeFromUnsuitableNodes(java.lang.String... items);
  public A removeAllFromUnsuitableNodes(Collection<String> items);
  public List<String> getUnsuitableNodes();
  public String getUnsuitableNode(int index);
  public String getFirstUnsuitableNode();
  public String getLastUnsuitableNode();
  public String getMatchingUnsuitableNode(Predicate<String> predicate);
  public Boolean hasMatchingUnsuitableNode(Predicate<String> predicate);
  public A withUnsuitableNodes(List<String> unsuitableNodes);
  public A withUnsuitableNodes(java.lang.String... unsuitableNodes);
  public Boolean hasUnsuitableNodes();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
